<?php

namespace SuperRhino\AppStoreServerApi\Response;

use Carbon\Carbon;

class ServerNotificationsPayload extends AbstractResponse implements EnvironmentInterface {

    /**
     * The in-app purchase event for which the App Store sent this version 2 notification.
     * @var string
     */
    public string $notificationType;

    /**
     * Additional information that identifies the notification event, or an empty string. The subtype applies only to select version 2 notifications.
     * @var string
     */
    public string $subtype;

    /**
     * A unique identifier for the notification. Use this value to identify a duplicate notification.
     * @var string
     */
    public string $notificationUUID;

    /**
     * The object that contains the app metadata and signed renewal and transaction information.
     */
    public ServerNotificationsPayloadData $data;

    public string $version;

    public Carbon $signedDate;

    public function parameterConverter($name, $value) {
        switch ($name) {
            case 'data':
                return new ServerNotificationsPayloadData($value);
            case 'signedDate':
                return Carbon::createFromTimestampMs($value);
            default:
                return $value;
        }
    }

    public function isSandbox(): bool {
        return $this->data->isSandbox();
    }

    public function isProduction(): bool {
        return $this->data->isProduction();
    }

}